(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.behaviors.quickShortcuts = {
    attach: function (context, settings) {
      if (!drupalSettings.quickShortcuts) {
        return;
      }

      const shortcuts = drupalSettings.quickShortcuts.items;
      const position = drupalSettings.quickShortcuts.position;
      const baseUrl = window.location.origin;

      // Create navbar if it doesn't exist
      if ($('.quick-shortcuts-navbar').length === 0) {
        const $navbar = $('<div class="quick-shortcuts-navbar"></div>');
        $navbar.addClass(position);

        if (!shortcuts || shortcuts.length === 0) {
          // Add message when no shortcuts are available
          const $message = $(`
            <div class="quick-shortcuts-empty">
              <span class="icon icon-help"></span>
              <span class="shortcut-text">No hay enlaces añadidos</span>
            </div>
          `);
          $navbar.append($message);
        } else {
          // Add shortcuts
          shortcuts.forEach(shortcut => {
            // Ensure path starts with a slash
            const path = shortcut.path.startsWith('/') ? shortcut.path : '/' + shortcut.path;
            // Construct full URL
            const fullUrl = baseUrl + path;
            
            const $link = $(`
              <a href="${fullUrl}" class="quick-shortcuts-item" target="_blank" rel="noopener noreferrer">
                <span class="icon icon-${shortcut.icon}"></span>
                <span class="shortcut-text">${shortcut.title}</span>
              </a>
            `);
            $navbar.append($link);
          });
        }

        $('body').append($navbar);
      }
    }
  };
})(jQuery, Drupal, drupalSettings);
